#
# spec file for package terminus-bitmap-fonts
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define fontname terminus-font
%define mainver 4.49
Name:           terminus-bitmap-fonts
Version:        4.49.1
Release:        bp155.3.10
Summary:        Readable Fixed Width Fonts for X11 and the Linux Console
License:        OFL-1.1
Group:          System/X11/Fonts
URL:            http://terminus-font.sf.net/
Source:         https://sf.net/projects/terminus-font/files/terminus-font-%{mainver}/terminus-font-%{version}.tar.gz
BuildRequires:  bdftopcf
BuildRequires:  dos2unix
BuildRequires:  fontpackages-devel
BuildRequires:  python3-devel >= 3.5
%reconfigure_fonts_prereq
Provides:       terminus-font
Provides:       locale(ru;bg)
BuildArch:      noarch

%description
Terminus Font is a geometric sans-serif font designed for long (8 and
more hours per day) work with computers. Version 4.03 contains 538
characters, covering code pages ISO8859-1/2/5/9/15/16,
Windows-1250/1251/1252/1254, IBM-437/852/855/866, KOI8-R/U/E/F,
Bulgarian-MIK, Paratype-PT154/PT254 and Macintosh-Ukrainian, and also
the vt100 and xterm pseudographic characters.

The sizes and styles present are 8x14-normal, 8x14-bold,
8x14-EGA/VGA-bold, 8x16-normal, 8x16-bold, 8x16-EGA/VGA-bold,
10x20-normal, 10x20-bold, 12x24-normal, 12x24-bold and 14x28-normal
(whose weight is actually between normal and bold).

This package installs the font(s) in psf format (Linux console)
and pcf (usable with e.g. libXft/xterm).
%if 0%{?suse_version} >= 1550
Pango (used by e.g. libvte/gnome-terminal/etc.) does not support pcf
(anymore). Use the consoleet-terminus-fonts package in this case.
%endif

%prep
%autosetup -n %{fontname}-%{version}
dos2unix OFL.TXT
%define psfdir %{_datadir}/kbd/consolefonts

%build
chmod +x ./configure
# not autoconf
./configure --prefix=%{_prefix}
make -e x11dir=%{_miscfontsdir} psfdir=%{psfdir}

%install
%make_install -e x11dir=%{_miscfontsdir} psfdir=%{psfdir}
rm -f %{buildroot}%{_miscfontsdir}/fonts.dir
pushd %{buildroot}%{psfdir}
    rename .psf.gz .psfu.gz *.psf.gz
popd
#
# Was once a patch, now a command here. Author and exact reason unknown,
# but recompression does not look all that bad -j.eng.
#
find "%buildroot" -type f "(" -name "*.pcf.gz" -o -name "*.psfu.gz" ")" \
	-exec gzip -dv "{}" "+"
find "%buildroot" -type f "(" -name "*.pcf.gz" -o -name "*.psfu.gz" ")" \
	-exec gzip -9v "{}" "+"

%reconfigure_fonts_scriptlets

%files
%license OFL.TXT
%doc README*
%{_miscfontsdir}
%{psfdir}
%dir %{_datadir}/kbd

%changelog
* Tue Nov 16 2021 Jan Engelhardt <jengelh@inai.de>
- Add note to package description about pango not supporting
  pcf bitmap fonts.
* Mon Dec 28 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.49.1
  * Fixed install-otb and uninstall-otb to use otbdir instead of
    x11dir.
* Sat Dec 26 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.49
  * Added Open Type Bitmap support.
  * Altered ascii grave in some sizes to be more useful as a
    back quote.
  * Fixed 21B5, added 21B2 and 21B3.
* Sun Jul 28 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.48
  * Added the basic 27 hebrew letters and sheqel, with uppercase
    height.
  * Some improvements in the font build scripts.
* Sun Dec 30 2018 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.47
  * Added 35 new characters (33 glyphs).
  * Replaced ao2-variant "ae" with ao1 "ae", it was too similar
    to "oe".
  * Some fixes and improvements (17 characters in various
    sizes/styles).
  * Significantly improved the font conversion tools. Python
    3.5.0 or Node 6.9.0 are now required to build the font.
- Spec cleanup
* Mon Jun 26 2017 aloisio@gmx.com
- Update to version 4.46
  * The X11 8-bit code pages are not installed by default.
  * Added IBM-437 8-bit code page for X11.
  * The CRT VGA weight for Linux console is not installed by default.
  * Removed the Linux console mapping files.
  * These should be provided by the console packages.
  * Removed the BSD console installation.
  * The recent BSD-s have a new console subsystem.
  * Added 50 new characters. Mostly math, but also Buglarian yat and yus.
  * Rewritten the font conversion tools in python/javascript.
  * The full unicode range (17x64K) is now supported.
  * The Windows installer can be built from sources.
  * Small fixes and improvements (7 characters in various sizes).
  * Renamed install-ref to install-psf-ref (uninstall too).
* Tue Apr 11 2017 aloisio@gmx.com
- Update to version 4.40
  * Added 6 combining accents as separate characters.
  * Added 14 letters with dot above / dot below.
  * Added partial subscript and superscript: all digits and 11
    letters.
  * Added 30+ math characters, notably large braces, brackets and
    parens.
  * Added unicode range 2800-28FF in two variants (br1 and br2).
  * A few small character fixes.
  * Altered configure to be a bit more POSIX compliant.
  * Replaced some obscure (un)install Makefile targets with
    variables.
- Set direct source URL
* Sat Nov 22 2014 aloisio@gmx.com
- Updated to version 4.39
  * Added ballot, checkmark, heavy ballot and heavy checkmark.
  * Changed HT, LF etc. in sizes 14 and 18-hi2 to be proportional to the letter height, not the matrix height.
  * Added the powerline characters E0A0..E0A2 and E0B0..E0B3.
  * Added diameter (2300) - same gluph as empty set (2205).
  * Small improvements in size 32.
* Fri Nov 22 2013 jengelh@inai.de
- Correct License field, update homepage URL and description to
  include font classification
- Kill terminus-bitmap-fonts.patch, we can do this in the .spec
* Sat Sep  1 2012 toms@opensuse.org
- Updated to version 4.38 (no changelog found)
- SPEC file changes
  . corrected patch terminus-bitmap-fonts.patch
  . corrected provides and obsoletes
* Wed Jul  4 2012 pgajdos@suse.cz
- amend spec file to reflect new font packaging scheme
  (see openFATE#313536);
* Sat Jun 30 2012 i@marguerite.su
- fix builds for 12.2
  * now bdftopcf is a separated package from xorg-x11.
* Thu May 17 2012 pgajdos@suse.com
- call spec-cleaner
* Thu May  3 2012 pgajdos@suse.com
- renamed terminus-font -> terminus-bitmap-fonts
* Thu Apr  8 2010 tiwai@suse.de
- remove unnecessary buildrequires for too old distros
* Sun Aug 30 2009 aj@suse.de
- Remove support for old distros.
- remove percent sign from changes for rpm 4.7.
* Sat Apr 18 2009 bernhard.walle@gmx.de
- update to 4.28.
* Wed Aug  9 2006 mfabian@suse.de
- update to 4.20.
* Tue Aug  8 2006 dmueller@suse.de
- install fonts under /usr/share/fonts
* Sun Mar 26 2006 ro@suse.de
- remove ifarched BuildReq (no ifarch in noarch package)
* Wed Mar  1 2006 mfabian@suse.de
- add "Provides: locale(ru;bg)".
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri May 20 2005 mfabian@suse.de
- update to 4.12.
* Fri Feb 11 2005 uli@suse.de
- added /usr/share/kbd directory to file list (no kbd package on s390*;
  console fonts being useless on s390* the clean fix would be to
  ifarch them, but this would make the package non-noarch)
* Fri Dec  3 2004 mfabian@suse.de
- update to 4.11.
- use new macro "%%run_suseconfig_fonts".
* Sun Jul 25 2004 ro@suse.de
- added kbd to neededforbuild
* Fri Mar 19 2004 mfabian@suse.de
- use %%suseconfig_fonts_prereq
* Tue Jan 20 2004 mfabian@suse.de
- add mmj's check for existence of sbin/conf.d/SuSEconfig.pango
  again.
* Tue Jan 20 2004 mfabian@suse.de
- update to 4.06.
- run SuSEconfig also in %%postun
* Mon Jan 12 2004 mmj@suse.de
- Also call SuSEconfig.pango
* Mon Jan 12 2004 mmj@suse.de
- Run SuSEconfig.fonts in %%post
* Mon Nov  3 2003 ro@suse.de
- updated neededforbuild
- don't build as root
* Tue Aug 19 2003 mfabian@suse.de
- new package: version 4.03.
